function [varargout] = styleguide(varargin)
% STYLEGUIDE Open or search the MATLAB Programming Style Guide Wiki
%   STYLEGUIDE by itself opens the MATLAB Programming Style Guide Wiki in
%   the MATLAB web browser.
%
%   STYLEGUIDE SEARCHTERM1 SEARCHTERM2 SEARCHTERM3 ... searches the style
%   guide for any number of provided search terms and opens the search
%   results page in the MATLAB web browser.
% 
%   STYLEGUIDE uses similar syntax to the WEB function with the exception
%   that it does not expect a URL. Rather, any number of search terms may
%   be used. All other inputs and outputs for WEB work for STYLEGUIDE, e.g.
%   [STAT, BROWSER, URL] = STYLEGUIDE(SEARCHTERM,'-NOTOOLBAR','-NEW').
% 
%   To request permission to edit the wiki, use the contact form at
%   http://www.mathworks.com/matlabcentral/fileexchange/authors/contact/101715
%
%   Examples:
%      styleguide naming conventions
%         searches the style guide for "naming+conventions."
%      
%      styleguide -browser
%         opens the style guide in the system web browser
%
%      [stat,h] = styleguide; 
%         opens the style guide. Use close(h) to close the browser window.
% 
%   See also WEB, HELP.

%   Copyright 2013 Sky Sartorius
%   Author  - Sky Sartorius
%   Contact - www.mathworks.com/matlabcentral/fileexchange/authors/101715

% Arguments that can be passed to WEB function besides the URL:
validWebArgs = {'-browser' '-display' '-helpbrowser' '-new' ...
    '-notoolbar' '-noaddressbox' '1'};

searchTerm = '';
isaWebArg = false(1,nargin);
for iArg = 1:nargin
    arg = strtrim(varargin{iArg});
    isWebArg = strcmpi({arg},validWebArgs);
    if any(isWebArg)
        isaWebArg(iArg) = true;      
    else
        searchTerm = [searchTerm '+' arg]; %#ok<AGROW>
    end
end



if ~isempty(searchTerm) % Search for something.
    baseUrl = 'https://sites.google.com/search/matlabstyleguidelines?query='; 
    searchTerm(1) = ''; % Remove leading +.
    append = '&universe=classic';
    link = [baseUrl searchTerm append];
else
    link = 'https://sites.google.com/site/matlabstyleguidelines/'; 
end

webArguments = lower(varargin(isaWebArg));
[varargout{1:nargout}] = web(link,webArguments{:});

% Revision history
%{
2013-03-13 First version
2013-03-14 Uploaded to file exchange
2013-03-15 
    Got rid of redundant if ~isempty(searchTerm) statement
    Added some comments and made the file adhere a bit more to the style 
    guide to reduce hypocrisy.
2020-01-22 Changes URLs to match new google sites search style.
%}
